@@ -25,8 +25,7 @@
 #include <QDebug>
 #include <KMessageBox>
 #include <klocalizedstring.h>
-#ifdef HAVE_QGPGME
-#include <boost/shared_ptr.hpp>
+#ifdef HAVE_GPGMEPP
 #include <gpgme.h>
 #include <gpgme++/context.h>
 #include <gpgme++/key.h>
@@ -55,14 +54,6 @@
 #define KWALLET_HASH_MD5        1 // unsupported
 #define KWALLET_HASH_PBKDF2_SHA512 2 // used when using kwallet with pam or since 4.13 version
 
-// this defines the required throw_exception function in the namespace boost
-namespace boost {
-  void throw_exception(std::exception const &e) {
-     qDebug() << "boost::throw_exception called: " << e.what();
-     // FIXME: how to notify the user in this case?
-  }
-}
-
 namespace KWallet
 {
 
@@ -95,8 +86,8 @@ static int getRandomBlock(QByteArray &randBlock)
 #else
 
     // First try /dev/urandom
-    if (QFile::exists("/dev/urandom")) {
-        QFile devrand("/dev/urandom");
+    if (QFile::exists(QStringLiteral("/dev/urandom"))) {
+        QFile devrand(QStringLiteral("/dev/urandom"));
         if (devrand.open(QIODevice::ReadOnly)) {
             int rc = devrand.read(randBlock.data(), randBlock.size());
 
@@ -110,8 +101,8 @@ static int getRandomBlock(QByteArray &randBlock)
 
     // If that failed, try /dev/random
     // FIXME: open in noblocking mode!
-    if (QFile::exists("/dev/random")) {
-        QFile devrand("/dev/random");
+    if (QFile::exists(QStringLiteral("/dev/random"))) {
+        QFile devrand(QStringLiteral("/dev/random"));
         if (devrand.open(QIODevice::ReadOnly)) {
             int rc = 0;
             int cnt = 0;
@@ -160,13 +151,13 @@ BackendPersistHandler *BackendPersistHandler::getPersistHandler(BackendCipherTyp
     switch (cipherType) {
     case BACKEND_CIPHER_BLOWFISH:
         return new BlowfishPersistHandler;
-#ifdef HAVE_QGPGME
+#ifdef HAVE_GPGMEPP
     case BACKEND_CIPHER_GPG:
         return new GpgPersistHandler;
-#endif // HAVE_QGPGME
+#endif // HAVE_GPGMEPP
     default:
         Q_ASSERT(0);
-        return 0;
+        return nullptr;
     }
 }
 
@@ -180,13 +171,13 @@ BackendPersistHandler *BackendPersistHandler::getPersistHandler(char magicBuf[12
         }
         return new BlowfishPersistHandler(useECBforReading);
     }
-#ifdef HAVE_QGPGME
+#ifdef HAVE_GPGMEPP
     if (magicBuf[2] == KWALLET_CIPHER_GPG &&
             magicBuf[3] == 0) {
         return  new GpgPersistHandler;
     }
-#endif // HAVE_QGPGME
-    return 0;    // unknown cipher or hash
+#endif // HAVE_GPGMEPP
+    return nullptr;    // unknown cipher or hash
 }
 
 int BlowfishPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &version, WId)
@@ -482,7 +473,7 @@ int BlowfishPersistHandler::read(Backend *wb, QFile &db, WId)
     return 0;
 }
 
-#ifdef HAVE_QGPGME
+#ifdef HAVE_GPGMEPP
 GpgME::Error initGpgME()
 {
     GpgME::Error err;
@@ -515,7 +506,7 @@ int GpgPersistHandler::write(Backend *wb, QSaveFile &sf, QByteArray &version, WI
         return -5;
     }
 
-    boost::shared_ptr< GpgME::Context > ctx(GpgME::Context::createForProtocol(GpgME::OpenPGP));
+    std::shared_ptr< GpgME::Context > ctx(GpgME::Context::createForProtocol(GpgME::OpenPGP));
     if (0 == ctx) {
         qDebug() << "Cannot setup OpenPGP context!";
         KMessageBox::errorWId(w, i18n("<qt>Error when attempting to initialize OpenPGP while attempting to save the wallet <b>%1</b>. Please fix your system configuration, then try again.</qt>"), wb->_name.toHtmlEscaped());
@@ -615,7 +606,7 @@ int GpgPersistHandler::read(Backend *wb, QFile &sf, WId w)
     }
 
 retry_label:
-    boost::shared_ptr< GpgME::Context > ctx(GpgME::Context::createForProtocol(GpgME::OpenPGP));
+    std::shared_ptr< GpgME::Context > ctx(GpgME::Context::createForProtocol(GpgME::OpenPGP));
     if (0 == ctx) {
         KMessageBox::errorWId(w, i18n("<qt>Error when attempting to initialize OpenPGP while attempting to open the wallet <b>%1</b>. Please fix your system configuration, then try again.</qt>", wb->_name.toHtmlEscaped()));
         qDebug() << "Cannot setup OpenPGP context!";
@@ -748,6 +739,6 @@ retry_label:
 
     return 0;
 }
-#endif // HAVE_QGPGME
+#endif // HAVE_GPGMEPP
 
 } // namespace
